@@ -1,9 +1,9 @@
-# TES.R  --- TOTAL ENVIRON STORAGE
-# INPUT = network model
-# OUTPUT = total environ throughput - unit and scaled
-#
-# Borrett | July 7, 2012
-# ---------------------------------------------------
+#' TES.R  --- TOTAL ENVIRON STORAGE
+#' INPUT = network model
+#' OUTPUT = total environ throughput - unit and scaled
+#'
+#' Borrett | July 7, 2012
+#' ---------------------------------------------------
 
 TES <- function(x,balance.override=FALSE){
 
@@ -11,7 +11,7 @@ TES <- function(x,balance.override=FALSE){
   if (class(x) != 'network'){warning('x is not a network class object')}
 
                                         #Check for balancing
-  if (balance.override == TRUE){}else{
+  if (balance.override){}else{
     if (any(list.network.attributes(x) == 'balanced') == FALSE){x%n%'balanced' = ssCheck(x)}
     if (x%n%'balanced' == FALSE){warning('Model is not balanced'); stop}
   }
